Block bootstrap standard errors for the EVBS regression model
Source:R/blockboot.R
evbs_block_boot.RdNonparametric moving-block bootstrap for the parameters of the EVBS regression model. Intended for series with residual serial dependence, where the standard errors obtained from the observed information under the independence assumption are optimistic.