Quantile function of the Extreme-Value Birnbaum-Saunders distribution
Source:R/distribution.R
qevbs.RdExact quantile function on the response scale. This is the function needed to compute return levels; the generalized extreme-value return-level formula does not apply to the EVBS response, since the response is a monotone transformation of a GEV variate rather than a GEV variate itself.